--[[

Funky Instance Name Generator (Fing)
v1.02 by Kristakis
http://AstrekAssociation.com/

This is an addon that calls the Fing Library
You can use /fing to see your instance name at any time


If you have any questions or comments, feel free to 
visit Astrek or PM me on the Firefall forums :)

]]--

-- uses
require './fing';
require 'string';
require 'lib/lib_Slash';
require 'lib/lib_InterfaceOptions';

-- const
local csDefaultFormat = 'You are in %n.';
local sVersion = '1.02';

-- vars
local bStartup = true;
local sFormat = '';


-- functions
function ShowMessage(message)
	-- writes a message to tab 1 in yellow
	Component.GenerateEvent('MY_SYSTEM_MESSAGE', {text=message});
end

function SetupInterfaceOptions()
	-- create options
	InterfaceOptions.AddTextInput({id='messageformat', label='Notification layout', default=csDefaultFormat, tooltip='Use %n for the name and %i for ID.'});
	InterfaceOptions.NotifyOnLoaded(true);
	InterfaceOptions.SetCallbackFunc(function(id, val) OnOptionChange({name=id, value=val}) end, 'Fing');	
end

-- events
function OnOptionChange(args)
	-- record option change
	local sOptionName = string.lower(args.name);
	if sOptionName == '__loaded' then 
		bStartup = false;
		OnShowInstanceName();
	elseif sOptionName == 'messageformat' then
		sFormat = args.value;
	end;
end

function OnShowInstanceName()
	-- show your instance name
	if bStartup == false then 
		local sDisplay = sFormat;
		sDisplay = sDisplay:gsub('%%n', fing.GetInstanceName());
		sDisplay = sDisplay:gsub('%%i', tostring(Chat.GetInstanceID()));
		ShowMessage('Fing: '..sDisplay);
	end;
end

function OnSlash(args)
	if args.text == '' then
		OnShowInstanceName();
	else
		if string.len(args.text) > 6 then
			ShowMessage('Fing: Instance '..tostring(args.text)..' is called '..fing.GetInstanceName(args.text)..'.');
		else
			ShowMessage('Fing: '..args.text..' does not appear to be a valid InstanceID.');
		end;
	end;
end

function OnComponentLoad()
	-- setup options
	SetupInterfaceOptions();
	-- register the slash command with the system
	LIB_SLASH.BindCallback({slash_list='fing', description='/fing [instance]: Shows the name of the specified instance', func=OnSlash});
	-- all done
	ShowMessage('Fing v'..sVersion..' Loaded');
end

-- end.